@@ -177,9 +177,9 @@ def main():
             source, target = FLAGS.translate.split(",")
             translator = Translator(source, target)
             subs = translator.translate(subs)
-            Subtitle.export_subtitle(local_subtitle_path, subs, aligned_subtitle_path, frame_rate, "utf-8")
+            Subtitle.save_subs_as_target_format(subs, local_subtitle_path, aligned_subtitle_path, frame_rate, "utf-8")
         else:
-            Subtitle.export_subtitle(local_subtitle_path, subs, aligned_subtitle_path, frame_rate)
+            Subtitle.save_subs_as_target_format(subs, local_subtitle_path, aligned_subtitle_path, frame_rate)
 
         log_loss = predictor.get_log_loss(voice_probabilities, subs)
         if log_loss is None or log_loss > FLAGS.max_logloss:
